==> kubernetes-model-admissionregistration-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/WebhookClientConfigFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface WebhookClientConfigFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent<A>> extends Fluent<A> {


    public String getCaBundle();
    public A withCaBundle(String caBundle);
    public Boolean hasCaBundle();
    public A withNewCaBundle(StringBuilder arg1);
    public A withNewCaBundle(int[] arg1,int arg2,int arg3);
    public A withNewCaBundle(char[] arg1);
    public A withNewCaBundle(StringBuffer arg1);
    public A withNewCaBundle(byte[] arg1,int arg2);
    public A withNewCaBundle(byte[] arg1);
    public A withNewCaBundle(char[] arg1,int arg2,int arg3);
    public A withNewCaBundle(byte[] arg1,int arg2,int arg3);
    public A withNewCaBundle(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewCaBundle(String arg1);
    
/**
 * This method has been deprecated, please use method buildService instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference getService();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference buildService();
    public A withService(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference service);
    public Boolean hasService();
    public A withNewService(String name,String namespace,String path,Integer port);
    public WebhookClientConfigFluent.ServiceNested<A> withNewService();
    public WebhookClientConfigFluent.ServiceNested<A> withNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference item);
    public WebhookClientConfigFluent.ServiceNested<A> editService();
    public WebhookClientConfigFluent.ServiceNested<A> editOrNewService();
    public WebhookClientConfigFluent.ServiceNested<A> editOrNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference item);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(int[] arg1,int arg2,int arg3);
    public A withNewUrl(char[] arg1);
    public A withNewUrl(StringBuffer arg1);
    public A withNewUrl(byte[] arg1,int arg2);
    public A withNewUrl(byte[] arg1);
    public A withNewUrl(char[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUrl(String arg1);
    public interface ServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReferenceFluent<WebhookClientConfigFluent.ServiceNested<N>> {

            public N and();
            public N endService();    }


}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1beta1/WebhookClientConfigFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface WebhookClientConfigFluent<A extends io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getCaBundle();
    public A withCaBundle(String caBundle);
    public Boolean hasCaBundle();
    public A withNewCaBundle(StringBuilder arg1);
    public A withNewCaBundle(int[] arg1,int arg2,int arg3);
    public A withNewCaBundle(char[] arg1);
    public A withNewCaBundle(StringBuffer arg1);
    public A withNewCaBundle(byte[] arg1,int arg2);
    public A withNewCaBundle(byte[] arg1);
    public A withNewCaBundle(char[] arg1,int arg2,int arg3);
    public A withNewCaBundle(byte[] arg1,int arg2,int arg3);
    public A withNewCaBundle(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewCaBundle(String arg1);
    
/**
 * This method has been deprecated, please use method buildService instead.
 * @return The buildable object.
 */
@Deprecated public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference getService();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference buildService();
    public A withService(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference service);
    public Boolean hasService();
    public A withNewService(String name,String namespace,String path,Integer port);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent.ServiceNested<A> withNewService();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent.ServiceNested<A> withNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference item);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent.ServiceNested<A> editService();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent.ServiceNested<A> editOrNewService();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent.ServiceNested<A> editOrNewServiceLike(io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReference item);
    public String getUrl();
    public A withUrl(String url);
    public Boolean hasUrl();
    public A withNewUrl(StringBuilder arg1);
    public A withNewUrl(int[] arg1,int arg2,int arg3);
    public A withNewUrl(char[] arg1);
    public A withNewUrl(StringBuffer arg1);
    public A withNewUrl(byte[] arg1,int arg2);
    public A withNewUrl(byte[] arg1);
    public A withNewUrl(char[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3);
    public A withNewUrl(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewUrl(String arg1);
    public interface ServiceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.ServiceReferenceFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1beta1.WebhookClientConfigFluent.ServiceNested<N>> {

            public N and();
            public N endService();    }


}
